@@ -11,6 +11,7 @@ FROM
   INNER JOIN SYS.EXTENDED_PROPERTIES EP
     ON EP.MAJOR_ID = C.OBJECT_ID AND EP.MINOR_ID = C.COLUMN_ID
 WHERE
-  O.TYPE = 'U'
+  O.IS_MS_SHIPPED != 1
+  AND O.TYPE = 'U'
   AND EP.CLASS = 1
   AND EP.NAME = 'MS_Description'
