@@ -13,3 +13,7 @@ FROM
     ON CONSTRAINTS.CONNAMESPACE = NAMESPACES.OID
   INNER JOIN PG_CATALOG.PG_CLASS TABLES
     ON CONSTRAINTS.CONRELID = TABLES.OID
+WHERE
+  NAMESPACES.NSPNAME NOT IN ('pg_catalog', 'information_schema')
+  AND NAMESPACES.NSPNAME !~ '^pg_toast'
+  AND TABLES.RELKIND IN ('r', 'v')
