@@ -1,6 +1,5 @@
 package com.example;
 
-import java.sql.Connection;
 import java.util.logging.Level;
 
 import schemacrawler.inclusionrule.RegularExpressionInclusionRule;
@@ -14,10 +13,11 @@ import schemacrawler.schemacrawler.LoadOptionsBuilder;
 import schemacrawler.schemacrawler.SchemaCrawlerOptions;
 import schemacrawler.schemacrawler.SchemaCrawlerOptionsBuilder;
 import schemacrawler.schemacrawler.SchemaInfoLevelBuilder;
-import schemacrawler.tools.databaseconnector.DatabaseConnectionSource;
-import schemacrawler.tools.databaseconnector.SingleUseUserCredentials;
 import schemacrawler.tools.utility.SchemaCrawlerUtility;
 import us.fatehi.utility.LoggingConfig;
+import us.fatehi.utility.datasource.DatabaseConnectionSource;
+import us.fatehi.utility.datasource.DatabaseConnectionSources;
+import us.fatehi.utility.datasource.MultiUseUserCredentials;
 
 public final class ApiExample {
 
@@ -42,10 +42,8 @@ public final class ApiExample {
             .withLoadOptions(loadOptionsBuilder.toOptions());
 
     // Get the schema definition
-    final Catalog catalog;
-    try (Connection connection = getConnection()) {
-      catalog = SchemaCrawlerUtility.getCatalog(connection, options);
-    }
+    final DatabaseConnectionSource dataSource = getDataSource();
+    final Catalog catalog = SchemaCrawlerUtility.getCatalog(dataSource, options);
 
     for (final Schema schema : catalog.getSchemas()) {
       System.out.println(schema);
@@ -64,10 +62,11 @@ public final class ApiExample {
     }
   }
 
-  private static Connection getConnection() {
+  private static DatabaseConnectionSource getDataSource() {
     final String connectionUrl = "jdbc:hsqldb:hsql://localhost:9001/schemacrawler";
-    final DatabaseConnectionSource dataSource = new DatabaseConnectionSource(connectionUrl);
-    dataSource.setUserCredentials(new SingleUseUserCredentials("sa", ""));
-    return dataSource.get();
+    final DatabaseConnectionSource dataSource =
+        DatabaseConnectionSources.newDatabaseConnectionSource(
+            connectionUrl, new MultiUseUserCredentials("sa", ""));
+    return dataSource;
   }
 }
